@@ -6,7 +6,7 @@ use Catmandu::AlephX;
 use Data::Dumper;
 use open qw(:std :utf8);
 
-my $aleph = Catmandu::AlephX->new(url => "http://aleph.ugent.be/X");
+my $aleph = Catmandu::AlephX->new(url => "http://borges1.ugent.be/X");
 
 my %args = (
   library => "rug50",
@@ -21,4 +21,4 @@ if($info->is_success){
   print Dumper($info->item_h);
 }else{
   say STDERR join('',@{$info->errors});
-} 
+}
