@@ -7,7 +7,7 @@ use Catmandu::Store::AlephX;
 use Catmandu::Exporter::MARC;
 use open qw(:std :utf8);
 
-my $bag = Catmandu::Store::AlephX->new(url => "http://aleph.ugent.be/X");
+my $bag = Catmandu::Store::AlephX->new(url => "http://borges1.ugent.be/X");
 
 my $exporter = Catmandu::Exporter::MARC->new(type => "ALEPHSEQ");
 
